IosNotifications

Struct IosNotifications 

pub struct IosNotifications<'w> { /* private fields */ }
access to the iOS notification system, pinned to the main thread by its NonSend

use bevy_ios_notifications::IosNotifications;

fn bevy_system(notifications: IosNotifications) {
    notifications.set_badge(0);
}

Implementations

Source

impl IosNotifications<'_>

pub fn get_badge(&self) -> i32

pub fn set_badge(&self, _value: i32)

pub fn show_foregrounded(&self) -> bool

whether notifications that fire while the app is in the foreground are presented

pub fn set_show_foregrounded(&self, _value: bool)

pub fn registered_for_push(&self) -> bool

pub fn register_for_push(&self)

pub fn schedule(&self, _request: IosNotificationRequest) -> String

pub fn request_permissions(&self, _permissions: IosNotificationPermissions)

pub fn request_pending(&self)

pub fn remove_pending(&self, _ids: &[String])

pub fn remove_delivered(&self, _ids: &[String])

pub fn remove_all_pending(&self)

remove all pending notifications

pub fn remove_all_delivered(&self)

remove all delivered notifications